@@ -1,16 +1,16 @@
 /* Copyright (C) 2008 The goocanvasmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -74,6 +74,7 @@ Window::on_item_button_press_event(const Glib::RefPtr<Goocanvas::Item>& item, Gd
     _drag_x = (int) event->x ;
     _drag_y = (int) event->y ;
   }
+  return false;
 }
 
 bool
@@ -83,6 +84,7 @@ Window::on_item_button_release_event(const Glib::RefPtr<Goocanvas::Item>& item,
   {
     _dragging.clear() ;
   }
+  return false;
 }
 
 bool
@@ -94,4 +96,5 @@ Window::on_item_motion_notify_event(const Glib::RefPtr<Goocanvas::Item>& item, G
     double new_y = event->y ;
     item->translate(new_x - _drag_x, new_y - _drag_y) ;
   }
+  return false;
 }
